@@ -2,6 +2,7 @@ import numpy as np
 import networkx as nx
 from networkx.algorithms.flow import maximum_flow
 from graphing.special_graphs.neural_trigraph.central_vert import NeuralTriGraphCentralVert
+from graphing.graph import Graph
 import re
 import random
 import collections
@@ -19,6 +20,9 @@ class NeuralTriGraph():
     def __init__(self, left_edges, right_edges):
         self.left_edges = left_edges
         self.right_edges = right_edges
+        edges = unify_edges(left_edges, right_edges)
+        self.max_ix = np.max(edges)
+        self.g1 = Graph(edges)
         self.vertices = set(left_edges.flatten())\
                     .union(set(right_edges.flatten()))
         self.layer_1 = set(left_edges[:,0])
@@ -42,6 +46,13 @@ class NeuralTriGraph():
         self.central_vert_dict = create_central_vert_dict(left_edges,\
                                                         right_edges)
 
+    def __eq__(self, other):
+        return self.left_edges == other.left_edges\
+            and self.right_edges == other.right_edges
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def create_bipartite_graph(self):
         self.flow_graph = nx.DiGraph()
         for ed in self.left_edges:
@@ -116,6 +127,18 @@ def is_valid_3_neural(edges1, edges2):
     return True
 
 
+def unify_edges(edges1, edges2):
+    edges = []
+    for e in edges1:
+        edges.append(e)
+
+    for e in edges2:
+        edges.append(e)
+
+    edges = np.array(edges)
+    return edges
+
+
 def tst1():
     ## Test case-1
     edges1 = np.array([[1,4],[2,4],[2,5],[3,5]])
